@@ -1,9 +1,10 @@
+import urllib
 from dez.buffer import Buffer
 from dez.op.server.frame import Frame, SendFrame
 from dez.http.client import HTTPClient
 
-#DELIM = "^@\r\n"
-DELIM = "\x00"
+DELIM = "^@\r\n"
+#DELIM = "\x00"
 
 class OPConnection(object):
     id = 0
@@ -43,14 +44,21 @@ class OPConnection(object):
             headers["function"] = func
             if url == True:
                 return self.write("CALLBACK", headers, body, cb, cbarg)
-            body += self.__parse_headers(headers)
+            final_headers = []
+            for key in headers:
+                if key == 'recipients':
+                    for recipient in headers['recipients']:
+                        final_headers.append(('recipient', recipient))
+                else:
+                    final_headers.append((key, headers[key]))
+            body = urllib.urlencode(final_headers)
             self.http.get_url(url, "POST", {}, cb, cbarg, body=body)
 
     def set_close_cb(self, cb, args=[]):
         self.conn.set_close_cb(cb, args)
 
     def __parse_headers(self, headers):
-        s = ""
+        s = ""        
         for key, val in headers.items():
             if key == "recipients":
                 for r in val:
@@ -60,6 +68,9 @@ class OPConnection(object):
         return s
 
     def __connect(self, data):
+        print 'CONNECT~!!'
+        print data
+        print
         req = Frame(self, Buffer(data, mode="consume"))
         if self.validator(req):
             if req.action != "CONNECT":
@@ -103,4 +114,4 @@ class OPConnection(object):
         self.conn.write(s, cb, cbarg)
 
     def close(self):
-        self.conn.close()
\ No newline at end of file
+        self.conn.close()
