@@ -18,16 +18,19 @@ class Frame(object):
                 key, val = key.strip(), val.strip()
                 problem_at = "headers: %s"%key
                 if key == "recipient":
+                    print 'found recipient', val
                     if "recipients" not in self.headers:
                         self.headers["recipients"] = []
-                    name, addr = val.split(",/",1)
-                    self.headers["recipients"].append((name,"/"+addr))
+                    self.headers["recipients"].append(val)
+#                    name, addr = val.split(",/",1)
+#                    self.headers["recipients"].append((name,"/"+addr))
                 else:
                     self.headers[key] = val
             buff.move(i+4)
             problem_at = "body"
             self.body = buff.data
         except:
+            raise
             self.problem = 'parse error in %s'%problem_at
 
     def error(self, msg, cb=None, cbarg=[]):
