@@ -1,11 +1,4 @@
-import event
-import sys
-if len(sys.argv) > 1:
-    engine = sys.argv[1]
-port = 8888
-if len(sys.argv) > 2:
-    port = int(sys.argv[2])
-
+import sys, event
 from dez.http.server import HTTPDaemon, HTTPResponse, RawHTTPResponse
 
 def test_dispatch(request):
