@@ -4,8 +4,7 @@ from dez.http.application import HTTPApplication
 def simple_app(environ, start_response):
     print 'POST DATA:'
     print environ['wsgi.input'].read()
-    print '===='
-    pprint.pprint(environ)
+    return []
     
 def main(port):
     httpd = HTTPApplication("127.0.0.1", port)
